function results = createResultsTable(inputs, materials, conditionBlocks)
%createResultsTable
%	Sets up the data table we want to save

    %unpack the inputs structure
    subjectID = inputs.subjectID;
    mainLanguage = inputs.mainLanguage;
    foreignLanguage = inputs.foreignLanguage;
    list = inputs.list;
    run = inputs.run;
    conditionOrder = inputs.conditionOrder;
    randSeed = inputs.randSeed;
    
    numTrials = length(conditionBlocks);
    
    resultsHdr = {'timestamp', 'subjectID', 'randSeed', 'mainLanguage', 'foreignLanguage',...
                  'list', 'run', 'order', 'trialNum', 'condition', 'audioFile', 'onset'};
	
    %results is the table that will hold all of the data we want to save
    results = cell(numTrials, length(resultsHdr));
    results = cell2table(results, 'VariableNames', resultsHdr);
    
    %Fill in the user input information
    results.subjectID(:) = {subjectID};
    results.mainLanguage(:) = {mainLanguage};
    results.foreignLanguage(:) = {foreignLanguage};
    
    results.randSeed = ones(numTrials,1)*randSeed;
    results.list     = ones(numTrials,1)*list;
	results.run      = ones(numTrials,1)*run;
    results.order    = ones(numTrials,1)*conditionOrder;
    
    %Fill in the info we already know
    results.timestamp(:) = {datestr(now)};
    results.trialNum = (1:numTrials)';
    results.condition = conditionBlocks;
    results.audioFile = materials;
    
    %NOTE: we'll record and save the actual onset times of each trial as we
    %go instead of saving the ideal onset times of each trial here
end