function fileToSave = getDataFilename(inputs)
%getDataFilename
%   Returns a string of the output filename and makes sure we don't
%   accidentally overwrite an existing file
    
    %Create the data diretory if it doesn't already exist
    subjectID = inputs.subjectID;
    mainLanguage = inputs.mainLanguage;
    foreignLanguage = inputs.foreignLanguage;
    list = inputs.list;
    run = inputs.run;
    usingForeignLanguage = inputs.usingForeignLanguage;
    
    if usingForeignLanguage
        dataDir = fullfile(pwd, 'data', '3conditions');
        filenameToSave = sprintf('%s_%s_%s_list%d_run%d.csv', ...
                                 subjectID, mainLanguage, ...
                                 foreignLanguage, list, run);
    else
        dataDir = fullfile(pwd, 'data', '2conditions');
        filenameToSave = sprintf('%s_%s_list%d_run%d.csv', ...
                                  subjectID, mainLanguage, list, run);
    end
    
    if ~exist(dataDir, 'dir')
        mkdir(dataDir);
    end
	
    fileToSave = fullfile(dataDir, filenameToSave);
    
    
	%Make sure we don't accidentally overwrite a previous data file
	if exist(fileToSave, 'file')
        fprintf('\nThe data file\n%s\nalready exists!\n\n', fileToSave);
        str = input('Overwrite? (y/n): ', 's');
        if ~(strcmpi(str,'y') || strcmpi(str,'yes'))
            error('The data file already exists for this subject!');
        end
	end
end