function validateInputs(inputs)
%validateInputs
%   makes sure all user inputs are the correct data types
    
	subjectID = inputs.subjectID;
    mainLanguage = inputs.mainLanguage;
    foreignLanguage = inputs.foreignLanguage;
    list = inputs.list;
    run = inputs.run;
    conditionOrder = inputs.conditionOrder;
    randSeed = inputs.randSeed;
    
    
    %subjectID is a string
    assert(ischar(subjectID), 'subjectID must be a string');
    
    %mainLanguage is a string
    assert(ischar(mainLanguage), 'mainLanguage must be a string');
    
    %foreignLanguage is a string
    assert(ischar(foreignLanguage), 'foreignLanguage must be a string');
    
    %list is 1 or 2
    assert(ismember(list, 1:2), 'list must be 1 or 2');
    
    %run and conditionOrder should be 1 or 2 if a foreign language is not given; 1-3 otherwise
    if isempty(foreignLanguage) || all(isspace(foreignLanguage))
        assert(ismember(run, 1:2), 'run must be 1 or 2');
        assert(ismember(conditionOrder, 1:2), 'conditionOrder must be 1 or 2');
    else
        assert(ismember(run, 1:3), 'run must be 1, 2, or 3');
        assert(ismember(conditionOrder, 1:3), 'conditionOrder must be 1, 2, or 3');
    end
    
    %randSeed must be provided on the first run and must be a positive integer
    if run == 1
        assert(~isempty(randSeed), 'randSeed must be provided on the first run');
        
        assert((isnumeric(randSeed)) && (randSeed>0) && (mod(randSeed,1)==0), ...
               'randSeed must be a positive integer');
    end
end